(menu-bar-mode -1)
(tool-bar-mode -1)
(scroll-bar-mode -1)
(ido-mode 1)

(defun other-window-reverse (&optional count)
  "Do other-window in reverse order."
  (interactive)
  (if (integerp count)
      (if (natnump count)
	  (other-window (- count))
	(other-window count))
    (other-window -1)))

(global-set-key (kbd "C-x p") 'other-window-reverse)

(require 'package)
(setq package-enable-at-startup nil)

(setq package-archives
      '(("gnu"          . "https://elpa.gnu.org/packages/")
        ("melpa"        . "https://melpa.org/packages/")
        ("melpa-stable" . "https://stable.melpa.org/packages/")))

(setq package-archive-priorities
      '(("gnu"          . 10)
        ("melpa"        . 20)
        ("melpa-stable" . 0)))

(package-initialize)

;; Bootstrap 'use-package
(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

(eval-when-compile
  (require 'use-package))
(custom-set-variables
 ;; custom-set-variables was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(custom-safe-themes
   '("b89a4f5916c29a235d0600ad5a0849b1c50fab16c2c518e1d98f0412367e7f97" "bffa9739ce0752a37d9b1eee78fc00ba159748f50dc328af4be661484848e476" default))
 '(package-selected-packages
   '(markdown-toc slime-repl-ansi-color slime geiser-chicken geiser-gambit geiser-guile rainbow-delimiters mustache mustache-mode emmet-mode smex hindent scheme-complete chicken-scheme flycheck-haskell haskell-mode vterm magit git markdown-mode markdown-mode+ easy-hugo chess flycheck-clojure flycheck-nim flycheck-nimsuggest flycheck cyberpunk-theme dashboard geiser nim-mode spacemacs-theme use-package)))
(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 )

(load-theme 'spacemacs-dark)
(use-package dashboard
  :ensure t
  :config
  (dashboard-setup-startup-hook))

(setq dashboard-startup-banner 'logo)
(add-hook 'after-init-hook #'global-flycheck-mode)

(setq-default flycheck-disabled-checkers '(emacs-lisp-checkdoc))

;; smex default M-x binding
(global-set-key (kbd "M-x") 'smex)

;; Keybind when working with git using magit
(global-set-key (kbd "C-x g") 'magit-status)

;; Org mode key bindings from the orgguide.pdf
(global-set-key (kbd "C-c l") 'org-store-link)
(global-set-key (kbd "C-c a") 'org-agenda)
(global-set-key (kbd "C-c c") 'org-capture)


;; Add Nim path when using choosenim, not needed if you used
;; your system's package manager.

(let* ((usrhome (getenv "HOME"))
      (local-bin (concat usrhome "/.local/bin"))
      (nimble-bin (concat usrhome "/.nimble/bin")))
  (setenv "PATH" (concat (getenv "PATH") ":" nimble-bin  ":" local-bin))
  (setq exec-path (append exec-path (list nimble-bin local-bin))))

;; Get rid of annoying backups
(setq backup-directory-alist
      `((".*" . ,temporary-file-directory)))

;; Geiser is lost, so let's tweak it
(use-package geiser
  :config
  (setq geiser-active-implementations '(chicken guile gambit))
  ;; Show matching parens
  (show-paren-mode 1))

;; Haskell interactive mode
(use-package haskell-mode
  :config
  (add-hook 'haskell-mode-hook 'interactive-haskell-mode))

;; Rainbow delimiters
(use-package rainbow-delimiters
  :config
  (add-hook 'scheme-mode-hook 'rainbow-delimiters-mode))

;; Mustache mode
(use-package mustache-mode)

;; Slime with sbcl
(use-package slime
  :config
  (setq inferior-lisp-program "sbcl"))

;; Extra hooks
(add-hook 'markdown-mode-hook 'markdown-toc-mode)
(add-hook 'mhtml-mode-hook 'emmet-mode)

;; Change default font for graphical frames
(add-to-list 'default-frame-alist
             '(font . "Jetbrains Mono-10"))

;; Don't open links in silly bloated browsers
(setq browse-url-browser-function #'eww-browse-url)
