Git commit signing with GPG
===========================

#### Check installation
```bash
$ gpg --version
```

#### Check for existing GPG keys
```bash
$ gpg --list-secret-keys --keyid-format LONG
```

#### Generate a new GPG key

For gpg 2.1.17 or greater:
```bash
$ gpg --full-generate-key
```

For gpg under 2.1.17:
```bash
$ gpg --default-new-key-algo rsa4096 --gen-key
```

## Configure git to use your GPG signing key

Copy the key ID from:
```bash
$ gpg --list-secret-keys --keyid-format LONG
```

And paste it on:
```bash
$ git config --global user.signingkey <paste here your key id>
```

Add your GPG key to your shell profile:
```bash
$ test -r ~/.bash_profile && echo 'export GPG_TTY=$(tty)' >> ~/.bash_profile
$ echo 'export GPG_TTY=$(tty)' >> ~/.profile
```

#### Asociate an email with your GPG key

Edit your profile including your email:
```bash
$ gpg --edit-key 3AA5C34371567BD2
```

Type the `adduid` command:
```bash
$ gpg> adduid
```

#### Sign a commit

Configure git client. For git 2.0.0 and above:
```bash
$ git config commit.gpgsign true
```

Sign all commits by default system wide:
```bash
$ git config --global commit.gpgsign true
```

Add `-S` each time you want a signed commit:
```bash
$ git commit -S -m "Your commit message"
```

Push your changes to remote:
```bash
$ git push
```

#### Sign a tag

Add the `-s` to your `git tag` command:
```bash
$ git tag -s <my-tag>
```

Verify your signed tag:
```bash
$ git tag -v <my-tag>
```

#### Add your GPG key to a remote git service (web).

Copy your key ID from:
```bash
$ gpg --list-secret-keys --keyid-format LONG
/home/user/.gnupg/secring.gpg
------------------------------------
sec   4096R/<copy this key id> 2016-03-10 [expires: 2017-03-10]
uid                          user 
ssb   4096R/42B317FD4BA89E7A 2016-03-10
```

Print out your GPG key:
```bash
$ gpg --armor --export <paste the key id here>
```

Copy the block that the previous command prints, and paste it on your web service text field for GPG key.

```bash
-----BEGIN PGP PUBLIC KEY BLOCK-----

... A bunch of random text ...

-----END PGP PUBLIC KEY BLOCK-----
```
