Git Over SSH Cheatsheet
=======================

Generate a new SSH Key:
```bash
$ ssh-keygen -t <dsa | ecdsa | ecdsa-sk | ed25519 | ed25529-sk | rsa> -b <bits> -C <comment | mail>
```

Start the `ssh-agent`:
```bash
$ eval "$(ssh-agent -s)"
```

Add private key to `ssh-agent`:
```bash
$ ssh-add ~/.ssh/<private key filename>
```

View agent available keys:
```bash
$ ssh-add -l
```

Test SSH connection:
```bash
$ ssh -T git@git.service.com
```

Add or change passphrase:
```bash
$ ssh-keygen -p
```

Copy the public key to add it to a service:
```bash
$ xclip -sel clip < ~/.ssh/id_rsa.pub
```

References:
[dsa]: <https://www.ietf.org/rfc/rfc3279.txt>
[ecdsa]: <https://tools.ietf.org/html/rfc6605>
[ecdsa-sk]: <https://www.openssh.com/txt/release-8.2>
[ed25519]: <https://tools.ietf.org/html/rfc8032>
[ed25519-sk]: <https://www.openssh.com/txt/release-8.2>
[rsa]: <https://tools.ietf.org/html/rfc8017>
[using ssh-agent]: <http://mah.everybody.org/docs/ssh>
